@@ -17,20 +17,17 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with damejson; see the file LICENSE.  If not, write to
+# along with dameformats; see the file LICENSE.  If not, write to
 # the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301 USA,
 
 import unittest
-import json
-import pandas as pd
 from xml.dom import minidom
-
 import xml.etree.ElementTree as ET
 
+class TestDameXml(unittest.TestCase):
 
-class TestDameJson(unittest.TestCase):
-
+    # XML
     def test_damexml_getelementsbytagname(self):
         # using read and loads to open
         xmldoc = minidom.parse('files/items.xml')
@@ -45,10 +42,36 @@ class TestDameJson(unittest.TestCase):
         tree = ET.parse('files/rss.xml')
         l1 = []
         for elem in tree.iter():
+            # using elem.tag
             if (elem.tag == "title"):
                 l1.append(elem.text)
         self.assertEqual(l1[0:2], ["Richard Stallman's Political Notes",
                                    'Economic growth and fossil fuels'])
+    def test_damexml_root(self):
+        tree = ET.parse('files/rss.xml')
+        root = tree.getroot()
+        self.assertEqual(root.tag, 'rss')
+        self.assertEqual(root.attrib, {'version': '2.0'})
+        l2 = []
+        for elem in root.iter():
+            if (elem.tag == "title"):
+                l2.append(elem.text)
+        self.assertEqual(l2[0:2], ["Richard Stallman's Political Notes",
+                                   'Economic growth and fossil fuels'])
+
+    def test_damexml_fromstring(self):
+        root = ET.fromstring('<a><b /><c><d /></c></a>')
+        self.assertEqual(root.tag, 'a')
+        self.assertEqual(root[0].tag, 'b')
+        self.assertEqual(root[1].tag, 'c')
+        self.assertEqual(root[1][0].tag, 'd')
+
+    def test_damexml_xpath(self):
+        tree = ET.parse("files/html.html")
+        p = tree.find("body/p")
+        links = list(p.iter("a"))
+        self.assertEqual(len(links), 2)
+
 
 
 if __name__ == '__main__':
